@@ -15,13 +15,11 @@ public class PagingToolBarX extends PagingToolBar {
 	}
 
 	public void fixPageTextWidth() {
-		pageText.getElement().getStyle()
-				.setProperty("width", "30px !important");
-		/*
-		 * 
-		 * pageText.getElement().setAttribute("style","width: 30px !important;"
-		 * + "margin: 0px;left: 108px;top: 2px;");
-		 */
+		pageText.getElement()
+				.setAttribute(
+						"style",
+						"width: 30px !important;"
+								+ "margin: 0px;left: 108px;top: 2px;");
 
 	}
 
